Update hipMathFunctions, hipTestHalf and hipTestNativeHalf tests to support Navi10 and Navi14. (#1545)
Αυτή η υποβολή περιλαμβάνεται σε:
@@ -29,7 +29,12 @@ THE SOFTWARE.
|
|||||||
#include "hip/hip_runtime.h"
|
#include "hip/hip_runtime.h"
|
||||||
#include "test_common.h"
|
#include "test_common.h"
|
||||||
|
|
||||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
|
#if __HIP_ARCH_GFX803__ || \
|
||||||
|
__HIP_ARCH_GFX900__ || \
|
||||||
|
__HIP_ARCH_GFX906__ || \
|
||||||
|
__HIP_ARCH_GFX908__ || \
|
||||||
|
__HIP_ARCH_GFX1010__ || \
|
||||||
|
__HIP_ARCH_GFX1012__
|
||||||
|
|
||||||
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
||||||
int tx = threadIdx.x;
|
int tx = threadIdx.x;
|
||||||
|
|||||||
@@ -28,7 +28,12 @@ THE SOFTWARE.
|
|||||||
|
|
||||||
#include "test_common.h"
|
#include "test_common.h"
|
||||||
|
|
||||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
|
#if __HIP_ARCH_GFX803__ || \
|
||||||
|
__HIP_ARCH_GFX900__ || \
|
||||||
|
__HIP_ARCH_GFX906__ || \
|
||||||
|
__HIP_ARCH_GFX908__ || \
|
||||||
|
__HIP_ARCH_GFX1010__ || \
|
||||||
|
__HIP_ARCH_GFX1012__
|
||||||
|
|
||||||
__device__ void test_convert() {
|
__device__ void test_convert() {
|
||||||
__half x;
|
__half x;
|
||||||
|
|||||||
@@ -32,7 +32,12 @@ THE SOFTWARE.
|
|||||||
|
|
||||||
using namespace std;
|
using namespace std;
|
||||||
|
|
||||||
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
|
#if __HIP_ARCH_GFX803__ || \
|
||||||
|
__HIP_ARCH_GFX900__ || \
|
||||||
|
__HIP_ARCH_GFX906__ || \
|
||||||
|
__HIP_ARCH_GFX908__ || \
|
||||||
|
__HIP_ARCH_GFX1010__ || \
|
||||||
|
__HIP_ARCH_GFX1012__
|
||||||
|
|
||||||
__global__
|
__global__
|
||||||
void __halfTest(bool* result, __half a) {
|
void __halfTest(bool* result, __half a) {
|
||||||
|
|||||||
Αναφορά σε νέο ζήτημα
Block a user